pub fn did_document_to_trust_anchor(
doc: &DidDocument,
name: Arc<Name>,
) -> Option<Certificate>Expand description
Attempt to reconstruct a trust anchor Certificate from a DidDocument.
Returns None if the document does not contain a recognised Ed25519 key.